@@ -22,6 +22,11 @@ EventDateRegion::EventDateRegion(double hours)
 {
 }
 
+EventDateRegion::EventDateRegion(time_t start, time_t stop)
+  : EventDate(start), duration(((double)stop - (double)start) / 60.0 / 60.0)
+{
+}
+
 EventDateRegion::EventDateRegion(const EventDate& orig, double dur)
   :EventDate(orig), duration(dur)
 {
