@@ -20,6 +20,7 @@
 
 #include <gtkmm.h>
 #include "event-date.h"
+#include <time.h>
 
 class EventDateRegion: public EventDate
 {
@@ -27,6 +28,8 @@ class EventDateRegion: public EventDate
 
         EventDateRegion(double hours = 0.0);
 
+        EventDateRegion(time_t start, time_t stop);
+
 	//! Copy constructor.
         EventDateRegion(const EventDateRegion& orig);
 
