@@ -81,3 +81,9 @@ void EventDate::decrement_to_nearest_interval(double hours)
     
   timeval.subtract_seconds(diff);
 }
+        
+double EventDate::subtract(EventDate point)
+{
+  double now = timeval.as_double();
+  return now - point.timeval.as_double();
+}
