@@ -17,9 +17,19 @@
 
 #include "config.h"
 #include "file.h"
+#include <glibmm.h>
 
 std::string File::get_data_path()
 {
-  return "/home/ben/play/listerola/dat";
+  return LISTEROLA_DATADIR;
 }
 
+std::string File::get_glade_path()
+{
+  return get_data_path() + "/glade";
+}
+    
+std::string File::get_user_config_file()
+{
+  return Glib::get_home_dir() + "/." + PACKAGE_NAME + "rc";
+}
