@@ -23,6 +23,8 @@ class File
 {
     public:
 	static std::string get_data_path();
+        static std::string get_glade_path();
+        static std::string get_user_config_file();
 
 };
 
