@@ -25,11 +25,12 @@ class Host;
 class HostBox: public FrameBox
 {
  public:
-     HostBox(Host *host, double row_height, double column_width);
+     HostBox(Host *host, bool show_name, bool show_numeric_id, double row_height, double column_width,
+             Pango::AttrList host_text_attributes);
      void set_host(Host *host);
     ~HostBox();
-
  private:
+    Pango::AttrList text_attributes;
 };
 
 #endif
