@@ -19,24 +19,32 @@
 #define HOSTLISTLOADER_H
 
 #include <string>
+#include <sigc++/signal.h>
 #include "host-list.h"
 #include "event-date.h"
+#include "listerola-options.h"
 
 //!Abstract class for objects that populate host lists.
 class HostListLoader
 {
     public:
         HostListLoader(HostList &hosts, std::string file, 
-                       EventDate starting_time);
+                       EventDate starting_time, ListerolaOptions::Source kind,
+                       bool &broken);
         virtual ~HostListLoader();
 
-        virtual void reload();
+        virtual void set_listing_file(std::string file);
 
-        virtual Gdk::Color genre_to_colour(std::string genre);
+        virtual bool reload();
+
+        ListerolaOptions::Source get_kind() const {return kind;};
+
+        sigc::signal<void> bad_file_format;
     protected:
         HostList &hostlist;
         std::string filename;
         EventDate starting_at;
+        ListerolaOptions::Source kind;
 };
 
 #endif //HOSTLISTLOADER_H
