@@ -18,11 +18,11 @@
 #ifndef HOSTLIST_H
 #define HOSTLIST_H
 
-#include <map>
+#include <list>
 
 #include "host.h"
 
-class HostList : public std::map<guint32, Host *>
+class HostList : public std::list<Host *>
 {
     public:
 
@@ -40,11 +40,16 @@ class HostList : public std::map<guint32, Host *>
 
         void set_active_host(Host *host) {active_host = host;};
 
-        Host *get_active_host() const {return active_host;};
+        Host* get_active_host();
+
+        Host *get_host_with_name(std::string name);
+
+        std::list<std::string> get_names();
 
         //! Clears all elements.
         void lClear();
 
+        std::list<std::string> get_genres();
     private:
 
         //! Erases an Item from the list and frees the element too.
