@@ -38,4 +38,4 @@ class HostedEventList : public EventList
 
 };
 
-#endif //EVENTLIST_H
+#endif //HOSTEDEVENTLIST_H
