@@ -22,6 +22,8 @@
 #include <string>
 #include <sigc++/connection.h>
 #include "event-date.h"
+#include <sigc++/signal.h>
+#include "listerola-view-options.h"
 
 
 class Listerola;
@@ -30,29 +32,24 @@ class FrameBox;
 class ListerolaWindow
 {
  public:
-    ListerolaWindow(Listerola &l, double num_row_channels, double tick_speed, 
-                    double row_pause, double flipahead_interval, 
-                    std::string advertisement_image_filename,
-                    double vertical_scroll_step, double row_height, 
-                    double hour_width, double channel_width);
-
-    void set_number_of_channels(double num_row_channels);
-    void set_scrolling_speed(double tick_speed);
-    void set_scrolling_row_pause(double row_pause);
-    void set_column_flipahead_time(double interval);
-    void set_advertisement_image(std::string image_filename, std::string wipestyle);
+    ListerolaWindow(Listerola &l, ListerolaViewOptions &opts, 
+                    Pango::AttrList event_text_attributes,
+                    Pango::AttrList host_text_attributes,
+                    Pango::AttrList header_text_attributes);
 
     Gtk::Window *get_window() {return window;};
-    bool run();
+    void show();
     void hide();
     
+    sigc::signal<void> quit_requested;
+    sigc::signal<void, std::list<std::string>, std::list<std::string> > open_preferences_requested;
+    sigc::signal<void, std::list<std::string> > update_genres_in_preferences_requested;
+    sigc::signal<void, std::list<std::string> > update_hosts_in_preferences_requested;
  private:
     Listerola &listerola;
+    ListerolaViewOptions &opts;
     Gtk::Window *window;
-    Gtk::Image *advertisement_image;
     Gtk::Viewport *listerola_viewport;
-    Gtk::Adjustment hadj;
-    Gtk::Adjustment vadj;
     Gtk::HBox *listing_hbox;
     Gtk::VBox *listing_vbox;
     Gtk::VBox *header_vbox;
@@ -61,44 +58,25 @@ class ListerolaWindow
     Gtk::VBox *scroll_vbox;
     Gtk::HBox *ad_hbox;
     Gtk::VBox *ad_vbox;
-  
     FrameBox* timebox;
-
-    //! The filename of the file that holds the channel listing data.
-    std::string listing_filename;
-
-    //! The number of channels shown at a time.
-    double row_channels;
-
-    //! The number of hours shown at a time.
-    double column_hours;
-
-    //! The speed at which we scroll rows.  milliseconds pause between pixels.
-    double scroll_speed;
-
-    //! The amount of time we wait while showing a row.
-    double scroll_row_pause;
-
-    //! How far in advance we show the next half hour.
-    double flipahead_interval;
-
-    int row_height;
+    Gtk::MenuBar *menubar;
+    Gtk::MenuItem *fullscreen_menuitem;
+    Gtk::MenuItem *quit_menuitem;
+    Gtk::MenuItem *preferences_menuitem;
+    Gtk::MenuItem *about_menuitem;
+    Gtk::Label *title_label;
 
     //! use this variable to add the on-deck hbox the first time through.
     bool add_more_rows;
 
-
-    //! The filename of the file that holds the current advertisement.
-    std::string advertisement_image_filename;
-
     //! The timer connection for the scrolling mechanism.
     sigc::connection scroll_tick_handler;
 
     //! the timer connection that runs every second.
     sigc::connection second_handler;
 
-    //must be a multiple of row_height
-    double vertical_scroll_step;
+    //how tall a scrolling row is in pixels.
+    int row_height;
 
     //how many pixels an hour takes up.
     double hour_width;
@@ -106,13 +84,26 @@ class ListerolaWindow
     //how many pixels a channel box takes up.
     double channel_width;
 
+    //how tall is the top title row?
+    double header_row_height;
+
+    bool window_is_fullscreen;
+
+    Pango::AttrList event_text_attributes;
+    Pango::AttrList host_text_attributes;
+    Pango::AttrList header_text_attributes;
+
     //helpers
     void update_listing_file(std::string listing_file);
-    void update_advertisement_image(std::string advertisement_image_file, std::string wipestyle);
     void update_scroll_box_size(double rows, double columns);
     void update_scrolling_speed(double tick_speed);
     Gtk::HBox *get_next_row();
     void fill_headers();
+    void calculate_heights_and_widths();
+    void update_scale_attribute(Pango::AttrList &attrs, double scale);
+    void update_background_colour();
+    void update_title();
+    std::list<std::string> get_uncoloured_genres();
 
     //! Callbacks
     bool on_vertical_scroll_tick();
@@ -121,7 +112,16 @@ class ListerolaWindow
     void on_row_scrolled(Gtk::HBox *row);
     bool on_second_passed();
     void on_column_scrolled();
-
+    void on_window_resized(Gtk::Allocation box);
+    void on_fullscreen_activated();
+    void on_quit_activated();
+    bool on_delete_event(GdkEventAny *e);
+    void on_preferences_activated();
+    void on_about_activated();
+    void on_scroll_speed_changed();
+    void on_background_colour_changed();
+    void on_genre_colours_changed();
+    void on_host_names_changed();
 
 };
 
