@@ -17,22 +17,17 @@
 
 #include "load-random-listing.h"
 
-LoadRandomListing::LoadRandomListing(HostList &hosts, std::string file, EventDate starting_time)
-  : HostListLoader(hosts, file, starting_time)
+LoadRandomListing::LoadRandomListing(HostList &hosts, std::string file, EventDate starting_time, bool &broken)
+  : HostListLoader(hosts, file, starting_time, ListerolaOptions::SOURCE_RANDOM, broken)
 {
-  reload();
+  broken = !reload();
 }
 
 LoadRandomListing::~LoadRandomListing()
 {
 }
 
-Gdk::Color LoadRandomListing::genre_to_colour(std::string genre)
-{
-  return Gdk::Color(genre);
-}
-
-void LoadRandomListing::reload()
+bool LoadRandomListing::reload()
 {
   HostList &channels = hostlist;
   channels.lClear();
@@ -40,10 +35,13 @@ void LoadRandomListing::reload()
   Event *show;
   char buf[32];
   std::string genre;
-  for (int i = 0; i < atoi(filename.c_str()); i++)
+  int max = atoi(filename.c_str());
+  if (max == 0)
+    max = 57;
+  for (int i = 0; i < max; i++)
     {
       snprintf (buf, sizeof (buf), "channel %d", i + 1);
-      channel = new Host (buf, i + 1);
+      channel = new Host (buf);
       channels.add (channel);
       EventDateRegion now = EventDateRegion(starting_at, 0);
   
@@ -53,12 +51,12 @@ void LoadRandomListing::reload()
 	  snprintf (buf, sizeof (buf), "ch%d show%d", i + 1, j + 1);
 	  switch (rand () % 6)
 	    {
-	    case 0: genre = "pink"; break;
-	    case 1: genre = "green"; break;
-	    case 2: genre = "red"; break;
-	    case 3: genre = "brown"; break;
-	    case 4: genre = "grey"; break;
-	    case 5: genre = "yellow"; break;
+	    case 0: genre = "Sports"; break;
+	    case 1: genre = "Film"; break;
+	    case 2: genre = "Children"; break;
+	    case 3: genre = "Soap"; break;
+	    case 4: genre = "News And Current Affairs"; break;
+	    case 5: genre = "Drama"; break;
 	    }
 	  show = new Event (buf, genre, now);
 	  channel->add (show);
@@ -66,4 +64,5 @@ void LoadRandomListing::reload()
 	  now.set_duration (double (((rand () % 4) + 1) * 0.5));
 	}
     }
+  return true;
 }
