@@ -22,10 +22,9 @@
 class LoadRandomListing: public HostListLoader
 {
     public:
-        LoadRandomListing(HostList &hostlist, std::string filename,EventDate starting_time);
+        LoadRandomListing(HostList &hostlist, std::string filename,EventDate starting_time, bool &broken);
         ~LoadRandomListing();
-        void reload();
-        Gdk::Color genre_to_colour(std::string genre);
+        bool reload();
 
 };
 #endif //LOADRANDOMLISTING_H
