@@ -22,10 +22,9 @@
 class LoadXmlTvListing: public HostListLoader
 {
     public:
-        LoadXmlTvListing(HostList &hostlist, std::string filename,EventDate starting_time);
+        LoadXmlTvListing(HostList &hostlist, std::string filename,EventDate starting_time, bool &broken);
         ~LoadXmlTvListing();
-        void reload();
-        Gdk::Color genre_to_colour(std::string genre);
+        bool reload();
 
 };
 #endif //LOADXMLTVLISTING_H
